==> nextcloud-app-calendar-1.5.3-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/calendar/l10n/sv.js <==
OC.L10N.register(
    "calendar",
    {
    "Calendar" : "Kalender",
    "%s has published the calendar \"%s\"" : "%s har publicerat kalendern \"%s\"",
    "Too many redirects. Aborting ..." : "För många omdirigeringar. Avbryter ...",
    "The remote server did not give us access to the calendar (HTTP {%s} error)" : "Externa servern gav inte åtkomst när vi försökte ansluta till kalendern (HTTP {%s} error)",
    "Error connecting to remote server" : "Ett fel uppstod med anslutningen till extern delning",
    "Error requesting resource on remote server. This could possible be related to a certificate mismatch" : "Ett fel uppstod när en resurs på externa servern skulle begäras. Detta kan vara relaterat till ett certifikat som inte matchar",
    "Error requesting resource on remote server" : "Ett fel uppstod när en resurs på externa servern skulle begäras ",
    "Individual" : "Individuell",
    "Group" : "Grupp",
    "Resource" : "Resurs",
    "Room" : "Rum",
    "Unknown" : "Okänt",
    "Required" : "Krävs",
    "Optional" : "Valfritt",
    "Does not attend" : "Kommer inte att delta",
    "{name} ({email})" : "{name} ({email})",
    "You are in an unknown timezone ({tz}), falling back to UTC" : "Du är i en okänd tidszon ({tz}), faller tillbaka på UTC",
    "Please create a calendar first." : "Vänlligen skapa en kalender först.",
    "New event" : "Ny händelse",
    "CalDAV address for clients" : "CalDAV adress för klienter",
    "Error saving WebCal-calendar" : "Ett fel uppstod när WebCal-kalendern sparades",
    "WebDAV address for subscriptions" : "WebDAV-adress för prenumerationer",
    "EMail has been sent." : "E-post skickades.",
    "There was an issue while sending your EMail." : "Det uppstod ett problem när e-post skulle skickas.",
    "group" : "Grupp",
    "Details" : "Detaljer",
    "Attendees" : "Deltagare",
    "Reminders" : "Påminnelser",
    "Repeating" : "Upprepa",
    "When shared show full event" : "Om delad, visa hela händelsen",
    "When shared show only busy" : "Om delad, visa endast upptagen",
    "When shared hide this event" : "Om delad, dölj denna händelse",
    "Confirmed" : "Bekräftad",
    "Tentative" : "Preliminärt",
    "Cancelled" : "Avbruten",
    "Please add a title!" : "Vänligen lägg till en titel!",
    "Please select a calendar!" : "Vänligen välj en kalender!",
    "The event ends before it starts!" : "Händelsen slutar innan den börjar!?",
    "Global" : "Global",
    "None" : "Ingen",
    "Every day" : "Varje dag",
    "Every week" : "Varje vecka",
    "Every month" : "Varje månad",
    "Every year" : "Varje år",
    "never" : "aldrig",
    "after" : "efter",
    "How about getting started by importing some calendars?" : "Vad sägs om att komma igång genom att importera några kalendrar?",
    "At time of event" : "På tid för event",
    "5 minutes before" : "5 minuter före",
    "10 minutes before" : "10 minuter före",
    "15 minutes before" : "15 minuter före",
    "30 minutes before" : "30 minuter före",
    "1 hour before" : "1 timme före",
    "2 hours before" : "2 timmar före",
    "Custom" : "special",
    "Audio" : "Ljud",
    "E Mail" : "E-post",
    "Pop up" : "Pop-up ",
    "sec" : "sek",
    "min" : "min",
    "hours" : "timmar",
    "days" : "dagar",
    "week" : "vecka",
    "before" : "före",
    "start" : "start",
    "end" : "slut",
    "Editing reminders of unknown type not supported." : "Att redigera påminnelser för okända typer stöds inte.",
    "Week {number} of {year}" : "Vecka {number} av {year}",
    "Successfully imported" : "Lyckad importering",
    "Partially imported, 1 failure" : "Delvis importerad, 1 fel",
    "Partially imported, {n} failures" : "Delvis importerad, {n} fel",
    "Audio alarm" : "Ringande alarm",
    "Pop-up" : "Pop-up ",
    "E-Mail" : "E-post",
    "{type} {time} before the event starts" : "{type} {time} före händelsen börjar",
    "{type} {time} before the event ends" : "{type} {time} före händelsen slutar",
    "{type} {time} after the event starts" : "{type} {time} efter händelsen börjar",
    "{type} {time} after the event ends" : "{type} {time} efter händelsen slutar",
    "{type} at the event's start" : "{type} vid händelsens början",
    "{type} at the event's end" : "{type} vid händelsens slut",
    "{type} at {time}" : "{type} vid {time}",
    "{calendar} shared by {owner}" : "{calendar} delad utav {owner}",
    "Please enter a valid WebCal-URL" : "Vänligen ange en giltig WebCal-URL",
    "Severe error in webcal proxy. Please contact administrator for more information." : "Allvarligt fel i webcal proxy. Vänligen kontakta administratören för vidare information.",
    "Title of the Event" : "Rubrik för händelsen",
    "Starts" : "Börjar",
    "Ends" : "Slutar",
    "All day Event" : "Heldag",
    "Delete" : "Radera",
    "Cancel" : "Avbryt",
    "More ..." : "Mer ...",
    "Create" : "Skapa",
    "Update" : "Uppdatera",
    "Close" : "Stäng",
    "Location" : "Plats",
    "Description" : "Beskrivning",
    "Event status" : "Händelsestatus",
    "Visibility when sharing" : "Synlighet när den delas",
    "Export" : "Exportera",
    "%s has published the calendar %s" : "%s har publicerat kalendern %s",
    "Hello," : "Hej,",
    "We wanted to inform you that %s has published the calendar {boldstart}%s{boldend}." : "Vi vill bara informera dig om att %s har publicerat kalendern {boldstart}%s{boldend}.",
    "Click here to access it" : "Klicka här för att komma åt den",
    "Cheers!" : "Ha de fint!",
    "We wanted to inform you that %s has published the calendar %s." : "Vi vill bara informera dig om att %s har publicerat kalendern %s.",
    "Click on the link below to access it" : "Klicka på länken nedan för att komma åt den",
    "Due to an upstream bug, the calendar is currently not able to provide support for the asset pipeline feature." : "På grund utav en bug uppströms, så kan inte calendar ge någon support för asset pipeline funktionen.",
    "Please contact your administrator and ask them to disable the \"asset-pipeline.enabled\" config option." : "Var god kontakta din administratör och be denne avaktivera \"asset-pipeline.enable\" inställningen.",
    "Day" : "Dag",
    "Week" : "Vecka",
    "Month" : "Månad",
    "Today" : "Idag",
    "Some events in this calendar are broken. Please check the JS console for more info." : "Några händelser i kalendern är felaktiga. Vänligen kolla JS-konsolen för mer information.",
    "Share Calendar" : "Dela kalender",
    "Shared" : "Delad",
    "More" : "Mer",
    "Edit" : "Ändra",
    "Link" : "Länk",
    "iCal link" : "iCal-länk",
    "Download" : "Ladda ned",
    "Share with users or groups" : "Dela med användare eller grupper",
    "can edit" : "kan redigera",
    "Share link" : "Dela länk",
    "Public access" : "Offentlig åtkomst",
    "Email link to person" : "E-posta länk till person",
    "Send" : "Skicka",
    "New Calendar" : "Ny kalender",
    "Name" : "Namn",
    "New Subscription" : "Ny prenumeration",
    "Go back" : "Gå framåt",
    "Go forward" : "Gå bakåt",
    "Edit event" : "Redigera händelse",
    "Delete Event" : "Radera händelse",
    "Save Event" : "Spara händelse",
    "Time" : "Tid",
    "Type" : "Typ",
    "Relative" : "Relativ",
    "Absolute" : "Absolut",
    "Repeat" : "Upprepa",
    "times every" : "gånger varje",
    "Add" : "Lägg till",
    "E-Mail address of attendee" : "E-postadress till deltagare",
    "Please add your email address in the personal settings in order to add attendees." : "Vänligen lägg till din e-postadress i personliga inställningar för att kunna lägga till deltagare.",
    "from" : "från",
    "to" : "till",
    "This event's repeating rule is not supported yet." : "Detta events repeteringsregel stöds inte ännu",
    "Support for advanced rules will be added with subsequent updates." : "Support för advancerade regler kommer läggas till i senare uppdateringar.",
    "Reset repeating rule" : "Radera repeteringsregeln",
    "Repeat every ..." : "Upprepa varje ...",
    "end repeat ..." : "sluta upprepa ...",
    "times" : "gånger",
    "Import Calendars" : "Importera kalender",
    "Import canceled" : "Importering avbruten",
    "Analyzing calendar" : "Analyserar kalender",
    "The file contains objects incompatible with the selected calendar" : "Filen innehåller objekt inkompatibla med den valda kalendern",
    "New calendar" : "Ny kalender",
    "File is empty" : "Filen är tom",
    "Import scheduled" : "Import schemalagd",
    "Publish URL" : "Publicera URL",
    "Settings & import" : "Inställningar & import",
    "Skip simple event editor" : "Använd inte den enkla händelse-redigeraren",
    "Show week numbers" : "Visa veckonummer",
    "Import calendar" : "Importera kalender",
    "No Calendars selected for import" : "Ingen kalender vald för import",
    "Primary CalDAV address" : "Primär CalDAV adress",
    "iOS/OS X CalDAV address" : "iOS/OS X CalDAV adress"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-calendar-1.5.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/calendar/l10n/sv.js <==
OC.L10N.register(
    "calendar",
    {
    "Calendar" : "Kalender",
    "%s has published the calendar »%s«" : "%s har publicerat kalender »%s«",
    "Hello," : "Hej,",
    "We wanted to inform you that %s has published the calendar »%s«." : "Vi vill informera dig att %s har publicerat kalendern »%s«.",
    "Open »%s«" : "Öppna »%s«",
    "Cheers!" : "Ha de fint!",
    "Recipient" : "Mottagare",
    "Too many redirects. Aborting ..." : "För många omdirigeringar. Avbryter ...",
    "The remote server did not give us access to the calendar (HTTP {%s} error)" : "Externa servern gav inte åtkomst när vi försökte ansluta till kalendern (HTTP {%s} error)",
    "Error connecting to remote server" : "Ett fel uppstod med anslutningen till extern delning",
    "Error requesting resource on remote server. This could possible be related to a certificate mismatch" : "Ett fel uppstod när en resurs på externa servern skulle begäras. Detta kan vara relaterat till ett certifikat som inte matchar",
    "Error requesting resource on remote server" : "Ett fel uppstod när en resurs på externa servern skulle begäras ",
    "Individual" : "Individuell",
    "Group" : "Grupp",
    "Resource" : "Resurs",
    "Room" : "Rum",
    "Unknown" : "Okänt",
    "Required" : "Krävs",
    "Optional" : "Valfritt",
    "Does not attend" : "Kommer inte att delta",
    "{name} ({email})" : "{name} ({email})",
    "You are in an unknown timezone ({tz}), falling back to UTC" : "Du är i en okänd tidszon ({tz}), faller tillbaka på UTC",
    "Please create a calendar first." : "Vänligen skapa en kalender först.",
    "New event" : "Ny händelse",
    "CalDAV address for clients" : "CalDAV adress för klienter",
    "Error saving WebCal-calendar" : "Ett fel uppstod när WebCal-kalendern sparades",
    "WebDAV address for subscriptions" : "WebDAV-adress för prenumerationer",
    "Email has been sent." : "E-post har skickats.",
    "There was an issue while sending your email." : "Det uppstod problem när e-post skickades till dig.",
    "group" : "Grupp",
    "Details" : "Detaljer",
    "Attendees" : "Deltagare",
    "Reminders" : "Påminnelser",
    "Repeating" : "Upprepa",
    "When shared show full event" : "Om delad, visa hela händelsen",
    "When shared show only busy" : "Om delad, visa endast upptagen",
    "When shared hide this event" : "Om delad, dölj denna händelse",
    "Confirmed" : "Bekräftad",
    "Tentative" : "Preliminärt",
    "Cancelled" : "Avbruten",
    "Please add a title." : "Var god lägg till en titel.",
    "Please select a calendar." : "Var god välj en kalender.",
    "The event can not end before it starts." : "Händelsen kan inte avslutas för den startats.",
    "Global" : "Global",
    "None" : "Ingen",
    "Every day" : "Varje dag",
    "Every week" : "Varje vecka",
    "Every month" : "Varje månad",
    "Every year" : "Varje år",
    "never" : "aldrig",
    "after" : "efter",
    "How about getting started by importing some calendars?" : "Vad sägs om att komma igång genom att importera några kalendrar?",
    "At time of event" : "På tid för event",
    "5 minutes before" : "5 minuter före",
    "10 minutes before" : "10 minuter före",
    "15 minutes before" : "15 minuter före",
    "30 minutes before" : "30 minuter före",
    "1 hour before" : "1 timme före",
    "2 hours before" : "2 timmar före",
    "Custom" : "special",
    "Audio" : "Ljud",
    "Email" : "E-post",
    "Pop-up" : "Pop-up ",
    "sec" : "sek",
    "min" : "min",
    "hours" : "timmar",
    "days" : "dagar",
    "week" : "vecka",
    "before" : "före",
    "start" : "start",
    "end" : "slut",
    "Editing reminders of unknown type not supported." : "Att redigera påminnelser för okända typer stöds inte.",
    "Week {number} of {year}" : "Vecka {number} av {year}",
    "Successfully imported" : "Lyckad importering",
    "Partially imported, 1 failure" : "Delvis importerad, 1 fel",
    "Partially imported, {n} failures" : "Delvis importerad, {n} fel",
    "Audio alarm" : "Ringande alarm",
    "{type} {time} before the event starts" : "{type} {time} före händelsen börjar",
    "{type} {time} before the event ends" : "{type} {time} före händelsen slutar",
    "{type} {time} after the event starts" : "{type} {time} efter händelsen börjar",
    "{type} {time} after the event ends" : "{type} {time} efter händelsen slutar",
    "{type} at the event's start" : "{type} vid händelsens början",
    "{type} at the event's end" : "{type} vid händelsens slut",
    "{type} at {time}" : "{type} vid {time}",
    "{calendar} shared by {owner}" : "{calendar} delad utav {owner}",
    "Please enter a valid WebCal-URL" : "Vänligen ange en giltig WebCal-URL",
    "Severe error in webcal proxy. Please contact administrator for more information." : "Allvarligt fel i webcal proxy. Vänligen kontakta administratören för vidare information.",
    "Title of the Event" : "Rubrik för händelsen",
    "Starts" : "Börjar",
    "Ends" : "Slutar",
    "All day Event" : "Heldag",
    "Delete" : "Radera",
    "Cancel" : "Avbryt",
    "More ..." : "Mer ...",
    "Create" : "Skapa",
    "Update" : "Uppdatera",
    "Close" : "Stäng",
    "Location" : "Plats",
    "Description" : "Beskrivning",
    "Event status" : "Händelsestatus",
    "Visibility when sharing" : "Synlighet när den delas",
    "Export" : "Exportera",
    "%s has published the calendar %s" : "%s har publicerat kalendern %s",
    "We wanted to inform you that %s has published the calendar {boldstart}%s{boldend}." : "Vi vill bara informera dig om att %s har publicerat kalendern {boldstart}%s{boldend}.",
    "Click here to access it" : "Klicka här för att komma åt den",
    "We wanted to inform you that %s has published the calendar %s." : "Vi vill bara informera dig om att %s har publicerat kalendern %s.",
    "Click on the link below to access it" : "Klicka på länken nedan för att komma åt den",
    "Day" : "Dag",
    "Week" : "Vecka",
    "Month" : "Månad",
    "Today" : "Idag",
    "Some events in this calendar are broken. Please check the JS console for more info." : "Några händelser i kalendern är felaktiga. Vänligen kolla JS-konsolen för mer information.",
    "Share Calendar" : "Dela kalender",
    "Shared" : "Delat",
    "More" : "Mer",
    "Edit" : "Ändra",
    "Link" : "Länk",
    "iCal link" : "iCal-länk",
    "Download" : "Ladda ned",
    "Share with users or groups" : "Dela med användare eller grupper",
    "can edit" : "kan redigera",
    "Share link" : "Dela länk",
    "Public access" : "Offentlig åtkomst",
    "Email link to person" : "E-posta länk till person",
    "Send" : "Skicka",
    "New Calendar" : "Ny kalender",
    "Name" : "Namn",
    "New Subscription" : "Ny prenumeration",
    "Go back" : "Gå framåt",
    "Go forward" : "Gå bakåt",
    "Calendar does not exist" : "Kalendern finns inte",
    "Maybe you got a wrong link or the calendar was unshared?" : "Du kanske fick en felaktig länk eller så har delningen av kalendern tagits bort?",
    "Edit event" : "Redigera händelse",
    "Delete Event" : "Radera händelse",
    "Save Event" : "Spara händelse",
    "Time" : "Tid",
    "Type" : "Typ",
    "Relative" : "Relativ",
    "Absolute" : "Absolut",
    "Repeat" : "Upprepa",
    "times every" : "gånger varje",
    "Add" : "Lägg till",
    "Email address of attendee" : "E-post-adresser av deltagare",
    "Please add your email address in the personal settings in order to add attendees." : "Vänligen lägg till din e-postadress i personliga inställningar för att kunna lägga till deltagare.",
    "from" : "från",
    "to" : "till",
    "This event's repeating rule is not supported yet." : "Detta events repeteringsregel stöds inte ännu",
    "Support for advanced rules will be added with subsequent updates." : "Support för avancerade regler kommer läggas till i senare uppdateringar.",
    "Reset repeating rule" : "Radera repeteringsregeln",
    "Repeat every ..." : "Upprepa varje ...",
    "end repeat ..." : "sluta upprepa ...",
    "times" : "gånger",
    "Import Calendars" : "Importera kalender",
    "Import canceled" : "Importering avbruten",
    "Analyzing calendar" : "Analyserar kalender",
    "The file contains objects incompatible with the selected calendar" : "Filen innehåller objekt inkompatibla med den valda kalendern",
    "New calendar" : "Ny kalender",
    "File is empty" : "Filen är tom",
    "Import scheduled" : "Import schemalagd",
    "%s shared the calendar <strong>%s</strong> with you" : "%s delade kalender <strong>%s</strong> med dig",
    "Embed" : "Bädda in",
    "Iframe to integrate" : "Iframe att integrera",
    "Publish URL" : "Publicera URL",
    "Settings & import" : "Inställningar & import",
    "Skip simple event editor" : "Använd inte den enkla händelse-redigeraren",
    "Show week numbers" : "Visa veckonummer",
    "Import calendar" : "Importera kalender",
    "No Calendars selected for import" : "Ingen kalender vald för import",
    "Primary CalDAV address" : "Primär CalDAV adress",
    "iOS/OS X CalDAV address" : "iOS/OS X CalDAV adress",
    "Subscribe" : "Prenumerera"
},
"nplurals=2; plural=(n != 1);");
